@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0400';
+our $VERSION = '0.0401';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -23,18 +23,25 @@ with('Music::PitchNum');
 
 has guitar => (
     is      => 'ro',
-    isa     => sub { croak 'not a boolean' unless $_[0] =~ /^[01]$/ },
+    isa     => \&_boolean,
     default => sub { 0 },
 );
 
 
 has modal => (
     is      => 'ro',
-    isa     => sub { croak 'not a boolean' unless $_[0] =~ /^[01]$/ },
+    isa     => \&_boolean,
     default => sub { 0 },
 );
 
 
+has chord_notes => (
+    is      => 'ro',
+    isa     => \&_boolean,
+    default => sub { 1 },
+);
+
+
 has keycenter => (
     is      => 'ro',
     isa     => sub { croak 'not a valid key' unless $_[0] =~ /^[A-G][#b]?$/ },
@@ -65,17 +72,22 @@ has scale => (
 
 has tonic => (
     is      => 'ro',
-    isa     => sub { croak 'not a boolean' unless $_[0] =~ /^[01]$/ },
+    isa     => \&_boolean,
     default => sub { 0 },
 );
 
 
 has verbose => (
     is      => 'ro',
-    isa     => sub { croak 'not a boolean' unless $_[0] =~ /^[01]$/ },
+    isa     => \&_boolean,
     default => sub { 0 },
 );
 
+sub _boolean {
+    my ($arg) = @_;
+    croak 'not a boolean' unless $arg =~ /^[01]$/;
+}
+
 
 sub generate {
     my ($self, $chord, $num, $next_chord) = @_;
@@ -126,12 +138,15 @@ sub generate {
     my @next_pitches = $next_scale ? get_scale_MIDI($next_chord_note, $self->octave, $next_scale) : ();
 
     # Add unique chord notes to the pitches
-    for my $n (@notes) {
-        if (not any { $_ == $n } @pitches) {
-            push @pitches, $n;
-            if ($self->verbose) {
-                my $x = $self->pitchname($n);
-                print "\tADD: $x\n";
+    if ($self->chord_notes) {
+        print "CHORD NOTES\n" if $self->verbose;
+        for my $n (@notes) {
+            if (not any { $_ == $n } @pitches) {
+                push @pitches, $n;
+                if ($self->verbose) {
+                    my $x = $self->pitchname($n);
+                    print "\tADD: $x\n";
+                }
             }
         }
     }
@@ -210,7 +225,7 @@ sub generate {
         $self->_verbose_notes('INTERSECT', @intersect) if $self->verbose;
         # Anticipate the next chord
         if (@intersect) {
-            if (my $closest = _closest($chosen[-2], \@intersect)) {
+            if (my $closest = _closest($chosen[-2] || $chosen[-1], \@intersect)) {
                 $chosen[-1] = $closest;
             }
         }
@@ -262,7 +277,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0400
+version 0.0401
 
 =head1 SYNOPSIS
 
@@ -290,7 +305,7 @@ a drop-in bass player.  Import rendered MIDI into a DAW and alter
 notes until they sound suitable.
 
 The "formula" implemented by this module is basically: "Play any notes
-of the chord, or chord-root scale."
+of the chord, modal chord scale, or chord-root scale."
 
 The chords recognized by this module, are those known to
 L<Music::Chord::Note>.  Please see the source of that module for the
@@ -314,6 +329,15 @@ Maintain the key-center and only choose notes within a mode.
 
 Default: C<0>
 
+=head2 chord_notes
+
+  $chord_notes = $bassline->chord_notes;
+
+Use unique chord notes that lie outside of the scale (e.g. C<b5>
+"flavor") for note choices.
+
+Default: C<1>
+
 =head2 keycenter
 
   $keycenter = $bassline->keycenter;
@@ -328,7 +352,7 @@ Default: C<C>
 
 Allowed intervals passed to L<Music::VoiceGen>.
 
-Default: C<-3 -2 -1 1 2 3>
+Default: C<[ -3 -2 -1 1 2 3 ]>
 
 =head2 octave
 
@@ -382,13 +406,14 @@ Default: C<0>
 
   $bassline = MIDI::Bassline::Walk->new;
   $bassline = MIDI::Bassline::Walk->new(
-      guitar    => $guitar,
-      intervals => $intervals,
-      octave    => $octave,
-      scale     => $scale,
-      modal     => $modal,
-      keycenter => $key_center,
-      verbose   => $verbose,
+      guitar      => $guitar,
+      intervals   => $intervals,
+      octave      => $octave,
+      scale       => $scale,
+      chord_notes => $chord_notes,
+      modal       => $modal,
+      keycenter   => $key_center,
+      verbose     => $verbose,
   );
 
 Create a new C<MIDI::Bassline::Walk> object.
